==> devpulse_cli-0.1.3.tar.gz: devpulse_cli-0.1.3/devpulse/commands/secrets.py <==
import typer

app = typer.Typer(help="Scan for secrets and sensitive data")


@app.command()
def scan(
    path: str = typer.Argument(".", help="Path to scan for secrets"),
    recursive: bool = typer.Option(True, "--recursive", "-r", help="Scan recursively")
):
    """
    Scan files for potential secrets and credentials.
    """
    typer.echo(f"🔐 Scanning path: {path}")
    typer.echo(f"Recursive: {recursive}")
    typer.echo("Scan complete! No secrets detected.")


@app.command()
def list():
    """
    List all detected secrets from previous scans.
    """
    typer.echo("📋 Secret Detection History:")
    typer.echo("No secrets found in database.")


@app.command()
def check(
    file_path: str = typer.Argument(..., help="File to check for secrets"),
    type: str = typer.Option(None, "--type", "-t", help="Secret type (api-key, password, token, etc.)"),
    strict: bool = typer.Option(False, "--strict", help="Use strict detection rules")
):
    """
    Check a specific file for secrets.
    """
    typer.echo(f"🔍 Checking file: {file_path}")
    if type:
        typer.echo(f"Filtering for: {type}")
    typer.echo(f"Strict mode: {strict}")
    typer.echo("✅ No secrets detected.")


@app.command()
def ignore(
    pattern: str = typer.Argument(..., help="Pattern or file to ignore"),
    remove: bool = typer.Option(False, "--remove", "-r", help="Remove from ignore list")
):
    """
    Add or remove patterns from the ignore list.
    """
    action = "Removed" if remove else "Added"
    typer.echo(f"✏️  {action} ignore pattern: {pattern}")
    typer.echo("Ignore list updated successfully!")


@app.command()
def report(
    format: str = typer.Option("console", "--format", "-f", help="Report format (console, json, html, sarif)"),
    output: str = typer.Option(None, "--output", "-o", help="Output file path"),
    severity: str = typer.Option("all", "--severity", "-s", help="Filter by severity (critical, high, medium, low)")
):
    """
    Generate a detailed security report.
    """
    typer.echo(f"📝 Generating security report ({format} format)")
    if severity != "all":
        typer.echo(f"Severity filter: {severity}")
    if output:
        typer.echo(f"Output: {output}")
    else:
        typer.echo("\n=== Security Report ===")
        typer.echo("No secrets detected.")


@app.command()
def validate(
    config_file: str = typer.Option(".secretscan.yml", "--config", "-c", help="Config file to validate")
):
    """
    Validate secret scanning configuration.
    """
    typer.echo(f"✔️  Validating config: {config_file}")
    typer.echo("Configuration is valid!")


@app.command()
def patterns(
    list_all: bool = typer.Option(False, "--list", "-l", help="List all detection patterns"),
    add: str = typer.Option(None, "--add", "-a", help="Add custom pattern"),
    remove: str = typer.Option(None, "--remove", "-r", help="Remove custom pattern")
):
    """
    Manage secret detection patterns.
    """
    if list_all:
        typer.echo("📋 Available detection patterns:")
        typer.echo("- API Keys\n- AWS Credentials\n- Private Keys\n- Tokens")
    elif add:
        typer.echo(f"➕ Added pattern: {add}")
    elif remove:
        typer.echo(f"➖ Removed pattern: {remove}")


@app.command()
def clean(
    path: str = typer.Argument(".", help="Path to clean"),
    backup: bool = typer.Option(True, "--backup", "-b", help="Create backup before cleaning"),
    dry_run: bool = typer.Option(False, "--dry-run", "-d", help="Show what would be removed")
):
    """
    Remove detected secrets from files (with backup).
    """
    typer.echo(f"🧹 Cleaning secrets from: {path}")
    typer.echo(f"Backup: {backup}")
    if dry_run:
        typer.echo("[DRY RUN] No files will be modified.")
    typer.echo("Clean operation completed!")

==> devpulse_cli-0.3.0.tar.gz: devpulse_cli-0.3.0/devpulse/commands/secrets.py <==
import typer

app = typer.Typer(help="Scan for secrets and sensitive data")


@app.command()
def scan(
    path: str = typer.Argument(".", help="Path to scan for secrets"),
    recursive: bool = typer.Option(True, "--recursive", "-r", help="Scan recursively")
):
    """
    Scan files for potential secrets and credentials.
    """
    typer.echo(f"🔐 Scanning path: {path}")
    typer.echo(f"Recursive: {recursive}")
    typer.echo("Scan complete! No secrets detected.")


@app.command()
def list():
    """
    List all detected secrets from previous scans.
    """
    typer.echo("[*] Secret Detection History:")
    typer.echo("No secrets found in database.")


@app.command()
def check(
    file_path: str = typer.Argument(..., help="File to check for secrets"),
    type: str = typer.Option(None, "--type", "-t", help="Secret type (api-key, password, token, etc.)"),
    strict: bool = typer.Option(False, "--strict", help="Use strict detection rules")
):
    """
    Check a specific file for secrets.
    """
    typer.echo(f"🔍 Checking file: {file_path}")
    if type:
        typer.echo(f"Filtering for: {type}")
    typer.echo(f"Strict mode: {strict}")
    typer.echo("✅ No secrets detected.")


@app.command()
def ignore(
    pattern: str = typer.Argument(..., help="Pattern or file to ignore"),
    remove: bool = typer.Option(False, "--remove", "-r", help="Remove from ignore list")
):
    """
    Add or remove patterns from the ignore list.
    """
    action = "Removed" if remove else "Added"
    typer.echo(f"✏️  {action} ignore pattern: {pattern}")
    typer.echo("Ignore list updated successfully!")


@app.command()
def report(
    format: str = typer.Option("console", "--format", "-f", help="Report format (console, json, html, sarif)"),
    output: str = typer.Option(None, "--output", "-o", help="Output file path"),
    severity: str = typer.Option("all", "--severity", "-s", help="Filter by severity (critical, high, medium, low)")
):
    """
    Generate a detailed security report.
    """
    typer.echo(f"📝 Generating security report ({format} format)")
    if severity != "all":
        typer.echo(f"Severity filter: {severity}")
    if output:
        typer.echo(f"Output: {output}")
    else:
        typer.echo("\n=== Security Report ===")
        typer.echo("No secrets detected.")


@app.command()
def validate(
    config_file: str = typer.Option(".secretscan.yml", "--config", "-c", help="Config file to validate")
):
    """
    Validate secret scanning configuration.
    """
    typer.echo(f"✔️  Validating config: {config_file}")
    typer.echo("Configuration is valid!")


@app.command()
def patterns(
    list_all: bool = typer.Option(False, "--list", "-l", help="List all detection patterns"),
    add: str = typer.Option(None, "--add", "-a", help="Add custom pattern"),
    remove: str = typer.Option(None, "--remove", "-r", help="Remove custom pattern")
):
    """
    Manage secret detection patterns.
    """
    if list_all:
        typer.echo("[*] Available detection patterns:")
        typer.echo("- API Keys\n- AWS Credentials\n- Private Keys\n- Tokens")
    elif add:
        typer.echo(f"➕ Added pattern: {add}")
    elif remove:
        typer.echo(f"➖ Removed pattern: {remove}")


@app.command()
def clean(
    path: str = typer.Argument(".", help="Path to clean"),
    backup: bool = typer.Option(True, "--backup", "-b", help="Create backup before cleaning"),
    dry_run: bool = typer.Option(False, "--dry-run", "-d", help="Show what would be removed")
):
    """
    Remove detected secrets from files (with backup).
    """
    typer.echo(f"🧹 Cleaning secrets from: {path}")
    typer.echo(f"Backup: {backup}")
    if dry_run:
        typer.echo("[DRY RUN] No files will be modified.")
    typer.echo("Clean operation completed!")
